@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2023 - 2024 Mikhail Medvedev <e-ink-reader@yandex.ru>
+ * Copyright (C) 2023 - 2025 Mikhail Medvedev <e-ink-reader@yandex.ru>
  *
  *
  * This program is free software; you can redistribute it and/or
@@ -17,6 +17,7 @@
 
 #include <QDialog>
 #include <QMessageBox>
+#include "hexutility.h"
 extern "C" {
 #include "ch341a_spi.h"
 #include "spi_controller.h"
@@ -38,17 +39,14 @@ private slots:
     void on_pushButton_clicked();
     void on_pushButton_2_clicked();
     void on_pushButton_3_clicked();
-    void r1Disable();
-    void r1Enable();
-    void r2Disable();
-    void r2Enable();
+    void setRegStatus(uint8_t regNumber, bool state);
+    void printRegData(uint8_t regNumber, uint8_t regData);
 
 signals:
     void closeRequestHasArrived();
 
 private:
     Ui::DialogSFDP *ui;
-    QString bP(unsigned char z);
     void setLineEditFilter();
     void legendPrint(QString basic, QString extended, QString manufacture);
     int numOfRegisters;
